---
name: Install issue
about: Tell us when the installation of SCALib fails.
title: ''
labels: ''
assignees: ''

---

**How do you install SCALib ?**

Explain what steps you followed to install SCALib.

Please give the exact commands you run.

If installing from git, what is the git commit id (`git rev-parse HEAD`) ?


**Observed behavior**

```
Paste the output of the install command here.
```

Provide any additional comment on the problematic behavior.

**Environment (please complete the following information):**
 - OS: [e.g. ubuntu 22.04]
- Python version: [output of `<python> -V` where `<python>` is how your run Python]
- numpy version: [output of `<python> -c "import numpy; print(numpy.__version__)"`]
- SCALib version (if install works): [output of `<python> -c "import scalib; print(scalib.__version__)"`]
- What CPU do you have? [intel, amd, ARM...]

**Additional context**
Add any other context about the problem or particularities about your configuration (e.g., environment variables, python install, etc.), or any issue different of "the install command crashes".
